# unspy

[![PyPI](http://img.shields.io/pypi/v/uns.svg)](https://pypi.python.org/pypi/uns)
[![Build](https://github.com/pylover/unspy/workflows/Build/badge.svg?branch=master)](https://github.com/pylover/unspy/actions)
[![Coverage Status](https://coveralls.io/repos/github/pylover/unspy/badge.svg?branch=master)](https://coveralls.io/github/pylover/unspy?branch=master)


UNS network discovery protocol implemented in pure python.
